pub struct InventoryDetails {
pub fulfillable_quantity: Option<i32>,
pub inbound_working_quantity: Option<i32>,
pub inbound_shipped_quantity: Option<i32>,
pub inbound_receiving_quantity: Option<i32>,
pub reserved_quantity: Option<Box<ReservedQuantity>>,
pub researching_quantity: Option<Box<ResearchingQuantity>>,
pub unfulfillable_quantity: Option<Box<UnfulfillableQuantity>>,
}Expand description
InventoryDetails : Summarized inventory details. This object will not appear if the details parameter in the request is false.
Fields
fulfillable_quantity: Option<i32>The item quantity that can be picked, packed, and shipped.
inbound_working_quantity: Option<i32>The number of units in an inbound shipment for which you have notified Amazon.
inbound_shipped_quantity: Option<i32>The number of units in an inbound shipment that you have notified Amazon about and have provided a tracking number.
inbound_receiving_quantity: Option<i32>The number of units that have not yet been received at an Amazon fulfillment center for processing, but are part of an inbound shipment with some units that have already been received and processed.
reserved_quantity: Option<Box<ReservedQuantity>>researching_quantity: Option<Box<ResearchingQuantity>>unfulfillable_quantity: Option<Box<UnfulfillableQuantity>>Implementations
sourceimpl InventoryDetails
impl InventoryDetails
sourcepub fn new() -> InventoryDetails
pub fn new() -> InventoryDetails
Summarized inventory details. This object will not appear if the details parameter in the request is false.